@@ -71,7 +71,7 @@ def location(host_os=None, card_os="raspberry", volume="boot"):
                 boot: /Volumes/boot
               ubuntu:
                 root: /Volumes/writable
-                boot: /Volume/system-boot
+                boot: /Volumes/system-boot
             ubuntu:
               raspberry:
                 root: /media/{user}/rootfs
@@ -247,7 +247,7 @@ class SDCard:
                 found = content != []
                 if found:
                     break
-            except:
+            except:  # noqa
                 pass
             print(f"read {filename} attempt {i}")
 
@@ -457,9 +457,9 @@ class SDCard:
         """
         Mounts the current SD card
         """
-        Sudo.password()
 
         if os_is_linux():
+            Sudo.password()
             dmesg = USB.get_from_dmesg()
 
             # TODO Need a better way to identify which sd card to use for mounting
@@ -475,10 +475,32 @@ class SDCard:
                     os.system(f"sudo eject -t {device}")
                     os.system('sudo sync')  # flush any pending/in-process writes
 
+                    # ensure the card is mounted before returning
+                    device_basename = os.path.basename(device)
+                    part1 = False
+                    part2 = False
+                    for i in range(10):
+                        result = Shell.run('lsblk')
+                        if device_basename in result.split():
+                            for line in result.splitlines():
+                                line = line.split()
+                                if device_basename + '1' in line[0] and len(line) > 6:
+                                    part1 = True
+                                elif device_basename + '2' in line[0] and len(line) > 6:
+                                    part2 = True
+                        if part1 and part2:
+                            # card is fully mounted
+                            break
+                        time.sleep(0.5)
+
+                    if not part1 and not part2:
+                        raise Exception("card failed to mount both partitions")
+
                 except Exception as e:
                     print(e)
 
         elif os_is_pi():
+            Sudo.password()
 
             if card_os is None:
                 Console.error("Please specify the OS you have on the SD Card")
@@ -534,18 +556,19 @@ class SDCard:
         :type device: str
         :param card_os:
         :type card_os:
+        :param full:
+        :type full:
         :return:
         :rtype:
         """
 
-        Sudo.password()
-
-        self.card_os = card_os
+        # self.card_os = card_os
 
         os.system('sudo sync')  # flush any pending/in-process writes
 
         os.system("sync")
         if os_is_linux() or os_is_pi():
+            Sudo.password()
             if full:
                 _execute(f"eject {device}", f"sudo eject {device}")
             else:
